diff --git a/coders/pdf.c b/coders/pdf.c
index 8da6eab..4170971 100644
--- a/coders/pdf.c
+++ b/coders/pdf.c
@@ -90,20 +90,18 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   I n v o k e P o s t s r i p t D e l e g a t e                             %
+%   I n v o k e P D F D e l e g a t e                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  InvokePostscriptDelegate() executes the postscript interpreter with the
 %  specified command.
 %
 %  The format of the InvokePostscriptDelegate method is:
 %
 %      MagickBooleanType InvokePostscriptDelegate(
 %        const MagickBooleanType verbose,const char *command,
 %        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -116,8 +114,8 @@
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static MagickBooleanType InvokePostscriptDelegate(
-  const MagickBooleanType verbose,const char *command,ExceptionInfo *exception)
+static MagickBooleanType InvokePDFDelegate(const MagickBooleanType verbose,
+  const char *command,ExceptionInfo *exception)
 {
   int
     status;
@@ -126,8 +124,8 @@
   char
     **argv;
 
-  const GhostscriptVectors
-    *gs_func;
+  const GhostInfo
+    *ghost_info;
 
   gs_main_instance
     *interpreter;
@@ -140,24 +138,24 @@
     i;
 
 #if defined(__WINDOWS__)
-  gs_func=NTGhostscriptDLLVectors();
+  ghost_info=NTGhostscriptDLLVectors();
 #else
-  GhostscriptVectors
-    gs_func_struct;
+  GhostInfo
+    ghost_info_struct;
 
-  gs_func=(&gs_func_struct);
-  (void) ResetMagickMemory(&gs_func,0,sizeof(gs_func));
-  gs_func_struct.new_instance=(int (*)(gs_main_instance **,void *))
+  ghost_info=(&ghost_info_struct);
+  (void) ResetMagickMemory(&ghost_info,0,sizeof(ghost_info));
+  ghost_info_struct.new_instance=(int (*)(gs_main_instance **,void *))
     gsapi_new_instance;
-  gs_func_struct.init_with_args=(int (*)(gs_main_instance *,int,char **))
+  ghost_info_struct.init_with_args=(int (*)(gs_main_instance *,int,char **))
     gsapi_init_with_args;
-  gs_func_struct.run_string=(int (*)(gs_main_instance *,const char *,int,int *))
-    gsapi_run_string;
-  gs_func_struct.delete_instance=(void (*)(gs_main_instance *))
+  ghost_info_struct.run_string=(int (*)(gs_main_instance *,const char *,int,
+    int *)) gsapi_run_string;
+  ghost_info_struct.delete_instance=(void (*)(gs_main_instance *))
     gsapi_delete_instance;
-  gs_func_struct.exit=(int (*)(gs_main_instance *)) gsapi_exit;
+  ghost_info_struct.exit=(int (*)(gs_main_instance *)) gsapi_exit;
 #endif
-  if (gs_func == (GhostscriptVectors *) NULL)
+  if (ghost_info == (GhostInfo *) NULL)
     {
       status=SystemCommand(verbose,command,exception);
       return(status == 0 ? MagickTrue : MagickFalse);
@@ -167,19 +165,19 @@
       (void) fputs("[ghostscript library]",stdout);
       (void) fputs(strchr(command,' '),stdout);
     }
-  status=(gs_func->new_instance)(&interpreter,(void *) NULL);
+  status=(ghost_info->new_instance)(&interpreter,(void *) NULL);
   if (status < 0)
     {
       status=SystemCommand(verbose,command,exception);
       return(status == 0 ? MagickTrue : MagickFalse);
     }
   argv=StringToArgv(command,&argc);
-  status=(gs_func->init_with_args)(interpreter,argc-1,argv+1);
+  status=(ghost_info->init_with_args)(interpreter,argc-1,argv+1);
   if (status == 0)
-    status=(gs_func->run_string)(interpreter,"systemdict /start get exec\n",0,
-      &code);
-  (gs_func->exit)(interpreter);
-  (gs_func->delete_instance)(interpreter);
+    status=(ghost_info->run_string)(interpreter,"systemdict /start get exec\n",
+      0,&code);
+  (ghost_info->exit)(interpreter);
+  (ghost_info->delete_instance)(interpreter);
 #if defined(__WINDOWS__)
   NTGhostscriptUnLoadDLL();
 #endif
@@ -617,7 +615,7 @@
     read_info->antialias != MagickFalse ? 4 : 1,
     read_info->antialias != MagickFalse ? 4 : 1,density,options,
     read_info->filename,postscript_filename,input_filename);
-  status=InvokePostscriptDelegate(read_info->verbose,command,exception);
+  status=InvokePDFDelegate(read_info->verbose,command,exception);
   pdf_image=(Image *) NULL;
   if ((status != MagickFalse) &&
       (IsPDFRendered(read_info->filename) != MagickFalse))
@@ -90,20 +90,18 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  InvokePostscriptDelegate() executes the postscript interpreter with the
-%  specified command.
+%  InvokePDFDelegate() executes the PDF interpreter with the specified command.
 %
@@ -90,20 +90,18 @@
 %
-%  The format of the InvokePostscriptDelegate method is:
+%  The format of the InvokePDFDelegate method is:
 %
@@ -90,20 +90,18 @@
 %
-%      MagickBooleanType InvokePostscriptDelegate(
-%        const MagickBooleanType verbose,const char *command,
-%        ExceptionInfo *exception)
+%      MagickBooleanType InvokePDFDelegate(const MagickBooleanType verbose,
+%        const char *command,ExceptionInfo *exception)
 %
 %  A description of each parameter follows: